"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownParser = void 0;
const tokenize_1 = require("./tokenize");
const parser_1 = require("./parser");
const plugins_1 = require("./plugins");
/**
 * Markdown parser class
 */
class MarkdownParser {
    plugins;
    useSyntaxHighlighting;
    constructor() {
        // Initialize with default plugins (excluding syntaxHighlightPlugin)
        this.plugins = [
            plugins_1.tablePlugin.bind(this),
            plugins_1.inlineStylesPlugin.bind(this),
            plugins_1.imagePlugin.bind(this),
            plugins_1.linkPlugin.bind(this),
        ];
        // Syntax highlighting is disabled by default
        this.useSyntaxHighlighting = false;
    }
    /**
     * Allows additional plugins to be registered
     * @param plugin A function that processes a token and returns HTML or null
     */
    use(plugin) {
        this.plugins.push(plugin);
        return this;
    }
    /**
     * Enables or disables syntax highlighting
     * @param enable A boolean indicating whether to enable syntax highlighting
     */
    enableSyntaxHighlighting(enable) {
        this.useSyntaxHighlighting = enable;
        if (enable) {
            // Add syntaxHighlightPlugin if not already present
            if (!this.plugins.includes(plugins_1.syntaxHighlightPlugin)) {
                this.plugins.push(plugins_1.syntaxHighlightPlugin.bind(this));
            }
        }
        else {
            // Remove syntaxHighlightPlugin if it exists
            this.plugins = this.plugins.filter((plugin) => plugin !== plugins_1.syntaxHighlightPlugin);
        }
        return this;
    }
    /**
     * Renders Markdown input into HTML
     * @param input The Markdown string to be rendered
     * @returns Rendered HTML string
     */
    render(input) {
        // Tokenize the input
        const tokens = (0, tokenize_1.tokenize)(input);
        // Parse the tokens into HTML
        return (0, parser_1.parse)(tokens, this.plugins);
    }
}
exports.MarkdownParser = MarkdownParser;
